dot-backdoor: Setup fasterRaster for ABS

.backdoorR Documentation

Setup fasterRaster for ABS

Description

This is a secret function to be used for faster development of fasterRaster. It calls faster() to set the install directory for GRASS, increases default memory, and number of cores. The function assumes development is on a Windows machine.

Usage

.backdoor(start = FALSE, ver = "84")

Arguments

start

Logical: If TRUE, start the GRASS session by creating the madElev GRaster.

ver

Character: GRASS: e.g., "83" or "84".

Value

TRUE (invisibly).


fasterRaster documentation built on April 18, 2026, 1:06 a.m.